mailr22807 - /trunk/data_store/__init__.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on April 17, 2014 - 19:14:
Author: bugman
Date: Thu Apr 17 19:14:39 2014
New Revision: 22807

URL: http://svn.gna.org/viewcvs/relax?rev=22807&view=rev
Log:
Changed the backward compatibility hook for old state files for the 
spectrometer frequency.

The behaviour has been changed so that the data pipe structure 
spectrometer_frq_list is now sorted.
This simply allows a number of tests to pass on Python 3.3+, a user would not 
notice any
differences.


Modified:
    trunk/data_store/__init__.py

Modified: trunk/data_store/__init__.py
URL: 
http://svn.gna.org/viewcvs/relax/trunk/data_store/__init__.py?rev=22807&r1=22806&r2=22807&view=diff
==============================================================================
--- trunk/data_store/__init__.py        (original)
+++ trunk/data_store/__init__.py        Thu Apr 17 19:14:39 2014
@@ -337,8 +337,9 @@
                     if frq not in dp.spectrometer_frq_list:
                         dp.spectrometer_frq_list.append(frq)
 
                 # And finally count the elements.
                 dp.spectrometer_frq_count = len(dp.spectrometer_frq_list)
+                dp.spectrometer_frq_list.sort()
 
 
     def add(self, pipe_name, pipe_type, bundle=None, switch=True):
@@ -337,8 +337,9 @@
                         dp.spectrometer_frq_list.append(frq)
 
-                # And finally count the elements.
+                # And finally count the elements and sort the list.
                 dp.spectrometer_frq_count = len(dp.spectrometer_frq_list)




Related Messages


Powered by MHonArc, Updated Thu Apr 17 19:40:02 2014